# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
from .forecast.client import ForecastClient
from ...core.client_wrapper import AsyncClientWrapper
from .forecast.client import AsyncForecastClient


class PastClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.forecast = ForecastClient(client_wrapper=self._client_wrapper)


class AsyncPastClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.forecast = AsyncForecastClient(client_wrapper=self._client_wrapper)
