# This file was auto-generated by Fern from our API Definition.

import typing

WeatherCode = typing.Union[
    typing.Literal["clear-night", "clear-day", "partly-cloudy-day", "partly-cloudy-night", "cloudy", "rain", "snow"],
    typing.Any,
]
